package uk.ac.leeds.ccg.grids;
/**
 * This file is distributed as part of the uk.ac.leeds.ccg.grids library 
 * for manipulating data stored in grids.
 * Copyright (C) 2002  Andy Turner
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
import uk.ac.leeds.ccg.raster.Raster;
import uk.ac.leeds.ccg.geotools.GeoRectangle;
import java.io.File;
import java.io.RandomAccessFile;
/**
 * Last updated 5 Nov 2002
 * @author  andyt
 * @version 1.0
 * A factory for creating Grid2DSquareCellDouble objects
 */
public class Grid2DSquareCellDoubleFactory extends AbstractGrid2DSquareCellDoubleFactory {
    
    /** Creates new Grid2DSquareCellDoubleFactory. */
    public Grid2DSquareCellDoubleFactory() {
    }
    
    // Methods return a Grid2DSquareCellDouble as an AbstractGrid2DSquareCellDouble
    
    public AbstractGrid2DSquareCellDouble createGrid2DSquareCellDouble( int nrows, int ncols, double xllcorner, double yllcorner, double cellsize, double noDataValue, int gridStatisticsType ) {
        return new Grid2DSquareCellDouble( nrows, ncols, xllcorner, yllcorner, cellsize, noDataValue, gridStatisticsType );
    }
    
    public AbstractGrid2DSquareCellDouble createGrid2DSquareCellDouble( AbstractGrid2DSquareCellDouble grid, int StartRowIndex, int StartColIndex, int EndRowIndex, int EndColIndex, int gridStatisticsType ) {
        return new Grid2DSquareCellDouble( grid, StartRowIndex, StartColIndex, EndRowIndex, EndColIndex, gridStatisticsType );
    }
    
    public AbstractGrid2DSquareCellDouble createGrid2DSquareCellDouble( File gridFile, int StartRowIndex, int StartColIndex, int EndRowIndex, int EndColIndex, int gridStatisticsType ) {
        return new Grid2DSquareCellDouble( gridFile, StartRowIndex, StartColIndex, EndRowIndex, EndColIndex, gridStatisticsType );
    }
    
    public AbstractGrid2DSquareCellDouble createGrid2DSquareCellDouble( Raster raster, int gridStatisticsType ) {
        return new Grid2DSquareCellDouble( raster, gridStatisticsType );
    }
    
    public String toString() {
        return "Grid2DSquareCellDoubleFactory";
    }
    
    public void setFile(File file) {
    }
    
    public String getDataDirectory() {
        return null;
    }
    
}
